library(ggplot2)
library(reshape2)
library("ggbeeswarm")
SingleViolinChart<-function(data,analysis, ymin, ymax, dotColor, xAxisLabel = "I am the X axis", yAxisLabel = "I am the Y Label"){
    g <- ggplot(data.frame(data), aes(x=0, y=data)) + 
        geom_violin(trim=FALSE, 
                    fill='#f0f0f0', 
                    color="white")+
        geom_dotplot(binaxis='y', 
                     stackdir='center', 
                     binwidth = ymax/80, 
                     fill=dotColor,
                     color="#f0f0f0")+
        coord_flip()+
        scale_y_continuous(limits = c(ymin,ymax)) +
        scale_color_grey() + 
        theme_classic()+
        geom_errorbar(aes(ymin=analysis$ci.min, ymax=analysis$ci.max),
                      width=0,                    
                      size = 1.4) +
        geom_point(data=data.frame(analysis$pointEstimate),
                   inherit.aes = FALSE,
                   aes(x=0,y=analysis$pointEstimate),
                   size=4, 
                   colour="black")+
        theme(panel.background = element_rect(fill = 'white', colour = 'white'),
              axis.title=element_text(size = rel(1.2), colour = "black"),
              axis.text=element_text(size = rel(1.2), colour = "black"),
              panel.grid.major = element_line(colour = "#DDDDDD"),
              panel.grid.major.y = element_blank(), 
              panel.grid.minor.y = element_blank(),
              axis.title.x=element_blank(),
              axis.text.y=element_blank(),
              axis.title.y=element_blank(),
              axis.ticks.y=element_blank(),
              axis.line.y = element_blank())
    return(g)
}