library(ggplot2)
library(reshape2)
library(ggpubr)
library(ggbeeswarm)
library("ggbeeswarm")
source("bootstrapCI.R")
source("plotting.R")
source("Plotting_helper2.R")


#########################################################
######### two techniques & the completion time ##########
#########################################################

data = read.table("../analysis_data/techniques.csv", header=T, sep=",")
data$completionTimePreNeighbor = log(data$completionTimePreNeighbor)
data = aggregate(data, by=list(P=data$P,Technique=data$Technique), FUN=mean, na.rm=TRUE)

TimeListSelection = subset(data, Technique=="ListSelection")$completionTimePreNeighbor
TimeExplosionSelection = subset(data, Technique=="ExplosionSelection")$completionTimePreNeighbor

TList = bootstrapMeanCI(TimeListSelection)
TExplosion = bootstrapMeanCI(TimeExplosionSelection)

meanListTime = exp(TList[1])
meanExplosionTime = exp(TExplosion[1])

cimaxL = exp(TList[3])
cimaxE = exp(TExplosion[3])

ciminL = exp(TList[2])
ciminE = exp(TExplosion[2])

analysisDataLT = c()
analysisDataLT$ratio = c("List")
analysisDataLT$pointEstimate = c(meanListTime)
analysisDataLT$ci.max = c(cimaxL)
analysisDataLT$ci.min = c(ciminL)

analysisDataET = c()
analysisDataET$ratio = c("Explosion")
analysisDataET$pointEstimate = c(meanExplosionTime)
analysisDataET$ci.max = c(cimaxE)
analysisDataET$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("List", "Explosion")
analysisData$pointEstimate = c(meanListTime, meanExplosionTime)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=50, ymax=100, "", "Completion Time per Technique in s. Error Bars, 95% CHIs")

figure_tech_meanTime <- ggarrange(SingleViolinChart(exp(TimeListSelection), analysisDataLT, 0, 250, '#E69F00'),
                    SingleViolinChart(exp(TimeExplosionSelection), analysisDataET, 0, 250, '#D5544B'),
                    labels = c("List", "Explosion"),
                    ncol = 1, nrow = 2
                    )


################# Differ
DiffListExpl = TimeListSelection - TimeExplosionSelection
T3 = bootstrapMeanCI(DiffListExpl)
mean3 = exp(T3[1])
cimax3 = exp(T3[3])
cimin3 = exp(T3[2])

analysisData3 = c()
analysisData3$ratio = c("List/Explosion")
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.6, ymax=1.5, "", "Pair-wise differences. Error Bars, CIs")

figure_tech_diffTime <- SingleViolinChart(exp(DiffListExpl), analysisData3, 0, 2.5, '#30A479')



#########################################################
##### three techniques influence in the correctness #####
#########################################################

data = read.table("../analysis_data/techniques.csv", header=T, sep=",")
data = aggregate(data, by=list(P=data$P,Technique=data$Technique), FUN=mean, na.rm=TRUE)

AccuracyListSelection = subset(data, Technique=="ListSelection")$Correctness
AccuracyExplosionSelection = subset(data, Technique=="ExplosionSelection")$Correctness

AList = bootstrapMeanCI(AccuracyListSelection)
AExplosion = bootstrapMeanCI(AccuracyExplosionSelection)

meanListAccuracy = AList[1]
meanExplosionAccuracy = AExplosion[1]
cimaxL = AList[3]
cimaxE = AExplosion[3]
ciminL = AList[2]
ciminE = AExplosion[2]

analysisDataLA = c()
analysisDataLA$ratio = c("List")    
analysisDataLA$pointEstimate = c(meanListAccuracy)
analysisDataLA$ci.max = c(cimaxL)
analysisDataLA$ci.min = c(ciminL)

analysisDataEA = c()
analysisDataEA$ratio = c("Explosion")   
analysisDataEA$pointEstimate = c(meanExplosionAccuracy)
analysisDataEA$ci.max = c(cimaxE)
analysisDataEA$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("ListSelection","ExplosionSelection")
analysisData$pointEstimate = c(meanListAccuracy, meanExplosionAccuracy)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=0.75, ymax=1.25, "", "Correctness per Technique in s. Error Bars, 95% CHIs")

figure_tech_meanAccuracy <- ggarrange(SingleViolinChart(AccuracyListSelection, analysisDataLA, 0.5, 1.5, '#E69F00'),
                     SingleViolinChart(AccuracyExplosionSelection, analysisDataEA, 0.5, 1.5, '#D5544B'),
                     labels = c("List", "Explosion"),
                     ncol = 1, nrow = 2
)

################# Differ

DivListExpl = AccuracyListSelection/AccuracyExplosionSelection
A3 = bootstrapMeanCI(DivListExpl)
mean3 = A3[1]
cimax3 = A3[3]
cimin3 = A3[2]

analysisData3 = c()
analysisData3$ratio = c("List/Explosion") 
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.75, ymax=1.25, "", "Pair-wise differences. Error Bars, CIs")

figure_tech_diffAccuracy <- SingleViolinChart(DivListExpl, analysisData3, 0.5, 2.0, '#30A479')




#########################################################
#three techniques influence in the valid clicking ratio #
#########################################################

data = read.table("../analysis_data/techniques.csv", header=T, sep=",")
data = aggregate(data, by=list(P=data$P,Technique=data$Technique), FUN=mean, na.rm=TRUE)

ValidListSelection = subset(data, Technique=="ListSelection")$ValidClickingRatio
ValidExplosionSelection = subset(data, Technique=="ExplosionSelection")$ValidClickingRatio

VList = bootstrapMeanCI(ValidListSelection)
VExplosion = bootstrapMeanCI(ValidExplosionSelection)

mean1 = VList[1]
mean2 = VExplosion[1]
cimax1 = VList[3]
cimax2 = VExplosion[3]
cimin1 = VList[2]
cimin2 = VExplosion[2]

analysisData1 = c()
analysisData1$ratio = c("List")
analysisData1$pointEstimate = c(mean1)
analysisData1$ci.max = c(cimax1)
analysisData1$ci.min = c(cimin1)

analysisData2 = c()
analysisData2$ratio = c("Explosion")
analysisData2$pointEstimate = c(mean2)
analysisData2$ci.max = c(cimax2)
analysisData2$ci.min = c(cimin2)

analysisData = c()
analysisData$ratio = c("ListSelection","ExplosionSelection")
analysisData$pointEstimate = c(VList[1], VExplosion[1])
analysisData$ci.max = c(VList[3], VExplosion[3])
analysisData$ci.min = c(VList[2], VExplosion[2])

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=0, ymax=70, "", "Correctness per Technique in s. Error Bars, 95% CHIs")

figure_tech_meanClicking <- ggarrange(SingleViolinChart(ValidListSelection, analysisData1, 0, 4, '#E69F00'),
                     SingleViolinChart(ValidExplosionSelection, analysisData2, 0, 4, '#D5544B'),
                     labels = c("List", "Explosion"),
                     ncol = 1, nrow = 2
)

########## diff
DivListExpl = ValidListSelection/ValidExplosionSelection
A3 = bootstrapMeanCI(DivListExpl)
mean3 = A3[1]
cimax3 = A3[3]
cimin3 = A3[2]

analysisData3 = c()
analysisData3$ratio = c("List/Explosion") 
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.75, ymax=1.25, "", "Pair-wise differences. Error Bars, CIs")

figure_tech_diffClicking <- SingleViolinChart(DivListExpl, analysisData3, 0, 1.5, '#30A479')



############ Discover Time

data = read.table("../analysis_data/discoverTime.csv", header=T, sep=",")
data$discoverTime = log(data$discoverTime)
data = aggregate(data, by=list(P=data$P,Technique=data$technique), FUN=mean, na.rm=TRUE)

TimeListSelection = subset(data, Technique=="ListSelection")$discoverTime
TimeExplosionSelection = subset(data, Technique=="ExplosionSelection")$discoverTime

TList = bootstrapMeanCI(TimeListSelection)
TExplosion = bootstrapMeanCI(TimeExplosionSelection)

meanListTime = exp(TList[1])
meanExplosionTime = exp(TExplosion[1])

cimaxL = exp(TList[3])
cimaxE = exp(TExplosion[3])

ciminL = exp(TList[2])
ciminE = exp(TExplosion[2])

analysisDataLT = c()
analysisDataLT$ratio = c("List") 
analysisDataLT$pointEstimate = c(meanListTime)
analysisDataLT$ci.max = c(cimaxL)
analysisDataLT$ci.min = c(ciminL)

analysisDataET = c()
analysisDataET$ratio = c("Explosion")   
analysisDataET$pointEstimate = c(meanExplosionTime)
analysisDataET$ci.max = c(cimaxE)
analysisDataET$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("List", "Explosion")  
analysisData$pointEstimate = c(meanListTime, meanExplosionTime)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=50, ymax=100, "", "Completion Time per Technique in s. Error Bars, 95% CHIs")

figure_tech_discoverTime <- ggarrange(SingleViolinChart(exp(TimeListSelection), analysisDataLT, 0, 20, '#E69F00'),
                    SingleViolinChart(exp(TimeExplosionSelection), analysisDataET, 0, 20, '#D5544B'),
                    labels = c("List", "Explosion"),
                    ncol = 1, nrow = 2
                    )


################# Differ
DiffListExpl = TimeListSelection - TimeExplosionSelection
T3 = bootstrapMeanCI(DiffListExpl)

mean3 = exp(T3[1])
cimax3 = exp(T3[3])
cimin3 = exp(T3[2])

analysisData3 = c()
analysisData3$ratio = c("1/2")
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.6, ymax=1.5, "", "Pair-wise differences. Error Bars, CIs")

figure_tech_discoverTimediff <- SingleViolinChart(exp(DiffListExpl), analysisData3, 0.5, 2.5, '#30A479')



############ Traversal Time

data = read.table("../analysis_data/discoverTime.csv", header=T, sep=",")
data$traversalTime = log(data$traversalTime)
data = aggregate(data, by=list(P=data$P,Technique=data$technique), FUN=mean, na.rm=TRUE)

TimeListSelection = subset(data, Technique=="ListSelection")$traversalTime
TimeExplosionSelection = subset(data, Technique=="ExplosionSelection")$traversalTime

TList = bootstrapMeanCI(TimeListSelection)
TExplosion = bootstrapMeanCI(TimeExplosionSelection)

meanListTime = exp(TList[1])
meanExplosionTime = exp(TExplosion[1])

cimaxL = exp(TList[3])
cimaxE = exp(TExplosion[3])

ciminL = exp(TList[2])
ciminE = exp(TExplosion[2])

analysisDataLT = c()
analysisDataLT$ratio = c("List") 
analysisDataLT$pointEstimate = c(meanListTime)
analysisDataLT$ci.max = c(cimaxL)
analysisDataLT$ci.min = c(ciminL)

analysisDataET = c()
analysisDataET$ratio = c("Explosion")
analysisDataET$pointEstimate = c(meanExplosionTime)
analysisDataET$ci.max = c(cimaxE)
analysisDataET$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("List", "Explosion")
analysisData$pointEstimate = c(meanListTime, meanExplosionTime)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=0, ymax=100, "", "Completion Time per Technique in s. Error Bars, 95% CHIs")

figure_tech_traTime <- ggarrange(SingleViolinChart(exp(TimeListSelection), analysisDataLT, 0, 200, '#E69F00'),
                    SingleViolinChart(exp(TimeExplosionSelection), analysisDataET, 0, 200, '#D5544B'),
                    labels = c("List", "Explosion"),
                    ncol = 1, nrow = 2
                    )


################# Differ

DiffListExpl = TimeListSelection - TimeExplosionSelection
T3 = bootstrapMeanCI(DiffListExpl)

mean3 = exp(T3[1])
cimax3 = exp(T3[3])
cimin3 = exp(T3[2])

analysisData3 = c()
analysisData3$ratio = c("List/Explosion")     # 1: list selection; 2: explosion view selection; 3: combination
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)


datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.6, ymax=1.5, "", "Pair-wise differences. Error Bars, CIs")

figure_tech_traTimediff <- SingleViolinChart(exp(DiffListExpl), analysisData3, 0.5, 2, '#30A479')



#########################################################
########## two positions & the completion time ##########
#########################################################

data = read.table("../analysis_data/position.csv", header=T, sep=",")
data$completionTimePreNeighbor = log(data$completionTimePreNeighbor)
data = aggregate(data, by=list(P=data$P,Position=data$Position,Technique=data$Technique), FUN=mean, na.rm=TRUE)

InsideListSelectionTime = subset(data, Position==0 & Technique=="ListSelection")$completionTimePreNeighbor
OutsideListSelectionTime = subset(data, Position==1 & Technique=="ListSelection")$completionTimePreNeighbor
InsideListT = bootstrapMeanCI(InsideListSelectionTime)
OutsideListT = bootstrapMeanCI(OutsideListSelectionTime)

InsideExplosionSelectionTime = subset(data, Position==0 & Technique=="ExplosionSelection")$completionTimePreNeighbor
OutsideExplosionSelectionTime = subset(data, Position==1 & Technique=="ExplosionSelection")$completionTimePreNeighbor
InsideExplosionT = bootstrapMeanCI(InsideExplosionSelectionTime)
OutsideExplosionT = bootstrapMeanCI(OutsideExplosionSelectionTime)

############ inside
meanListInsideTime = exp(InsideListT[1])
meanExplosionInsideTime = exp(InsideExplosionT[1])
cimaxInL = exp(InsideListT[3])
cimaxInE = exp(InsideExplosionT[3])
ciminInL = exp(InsideListT[2])
ciminInE = exp(InsideExplosionT[2])

analysisDataLTIn = c()
analysisDataLTIn$ratio = c("inList")
analysisDataLTIn$pointEstimate = c(meanListInsideTime)
analysisDataLTIn$ci.max = c(cimaxInL)
analysisDataLTIn$ci.min = c(ciminInL)

analysisDataETIn = c()
analysisDataETIn$ratio = c("inExplosion")
analysisDataETIn$pointEstimate = c(meanExplosionInsideTime)
analysisDataETIn$ci.max = c(cimaxInE)
analysisDataETIn$ci.min = c(ciminInE)

analysisData = c()
analysisData$ratio = c("inList", "inExplosion")
analysisData$pointEstimate = c(meanListInsideTime, meanExplosionInsideTime)
analysisData$ci.max = c(cimaxInL, cimaxInE)
analysisData$ci.min = c(ciminInL, ciminInE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=4, ymax=8, "", "Completion Time per Technique in s. Error Bars, 95% CHIs")

figure_position_meanTimeIn <- ggarrange(SingleViolinChart(exp(InsideListSelectionTime), analysisDataLTIn, 0, 250, '#E69F00'),
                    SingleViolinChart(exp(InsideExplosionSelectionTime), analysisDataETIn, 0, 250, '#D5544B'),
                    labels = c("inList", "inExplosion"),
                    ncol = 1, nrow = 2
                    )

################# Differ
DiffListExplIn = InsideListSelectionTime - InsideExplosionSelectionTime
T3 = bootstrapMeanCI(DiffListExplIn)
mean3 = exp(T3[1])
cimax3 = exp(T3[3])
cimin3 = exp(T3[2])

analysisData3 = c()
analysisData3$ratio = c("List/Explosion")
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.6, ymax=1.5, "", "Pair-wise differences. Error Bars, CIs")

figure_position_diffTimeIn <- SingleViolinChart(exp(DiffListExplIn), analysisData3, 0, 2.5, '#30A479')


############ outside
meanListOutsideTime = exp(OutsideListT[1])
meanExplosionOutsideTime = exp(OutsideExplosionT[1])
cimaxOutL = exp(OutsideListT[3])
cimaxOutE = exp(OutsideExplosionT[3])
ciminOutL = exp(OutsideListT[2])
ciminOutE = exp(OutsideExplosionT[2])

analysisDataLTOut = c()
analysisDataLTOut$ratio = c("OutList")
analysisDataLTOut$pointEstimate = c(meanListOutsideTime)
analysisDataLTOut$ci.max = c(cimaxOutL)
analysisDataLTOut$ci.min = c(ciminOutL)

analysisDataETOut = c()
analysisDataETOut$ratio = c("OutExplosion")
analysisDataETOut$pointEstimate = c(meanExplosionOutsideTime)
analysisDataETOut$ci.max = c(cimaxOutE)
analysisDataETOut$ci.min = c(ciminOutE)

analysisData = c()
analysisData$ratio = c("OutList", "OutExplosion")
analysisData$pointEstimate = c(meanListOutsideTime, meanExplosionOutsideTime)
analysisData$ci.max = c(cimaxOutL, cimaxOutE)
analysisData$ci.min = c(ciminOutL, ciminOutE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=4, ymax=10, "", "Completion Time per Technique in s. Error Bars, 95% CHIs")

figure_position_meanTimeOut <- ggarrange(SingleViolinChart(exp(OutsideListSelectionTime), analysisDataLTOut, 0, 250, '#E69F00'),
                    SingleViolinChart(exp(OutsideExplosionSelectionTime), analysisDataETOut, 0, 250, '#D5544B'),
                    labels = c("Out1", "Out2"),
                    ncol = 1, nrow = 2
                    )


################# Differ

DiffListExplOut = OutsideListSelectionTime - OutsideExplosionSelectionTime
T3 = bootstrapMeanCI(DiffListExplOut)
mean3 = exp(T3[1])
cimax3 = exp(T3[3])
cimin3 = exp(T3[2])

analysisData3 = c()
analysisData3$ratio = c("List/Explosion")
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.6, ymax=1.5, "", "Pair-wise differences. Error Bars, CIs")

figure_position_diffTimeOut <-SingleViolinChart(exp(DiffListExplOut), analysisData3, 0, 2.5, '#30A479')


##############################################
########## two positions & accuracy ##########
##############################################

# Inside cell
data = read.table("../analysis_data/position.csv", header=T, sep=",")
data = aggregate(data, by=list(P=data$P,Position=data$Position,Technique=data$Technique), FUN=mean, na.rm=TRUE)

AccuracyListSelectionIn = subset(data, Position==0 & Technique=="ListSelection")$correctness
AccuracyExplosionSelectionIn = subset(data, Position==0 & Technique=="ExplosionSelection")$correctness

AList = bootstrapMeanCI(AccuracyListSelectionIn)
AExplosion = bootstrapMeanCI(AccuracyExplosionSelectionIn)

cimaxL = AList[3]
cimaxE = AExplosion[3]

ciminL = AList[2]
ciminE = AExplosion[2]

meanListAccuracy = AList[1]
meanExplosionAccuracy = AExplosion[1]

analysisDataLA = c()
analysisDataLA$ratio = c("List") 
analysisDataLA$pointEstimate = c(meanListAccuracy)
analysisDataLA$ci.max = c(cimaxL)
analysisDataLA$ci.min = c(ciminL)

analysisDataEA = c()
analysisDataEA$ratio = c("Explosion")
analysisDataEA$pointEstimate = c(meanExplosionAccuracy)
analysisDataEA$ci.max = c(cimaxE)
analysisDataEA$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("ListSelection","ExplosionSelection")
analysisData$pointEstimate = c(meanListAccuracy, meanExplosionAccuracy)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=0.8, ymax=1.1, "", "Correctness per Technique in s. Error Bars, 95% CHIs")

figure_position_meanAccuracyIn <- ggarrange(SingleViolinChart(AccuracyListSelectionIn, analysisDataLA, 0.5, 1.5, '#E69F00'),
                     SingleViolinChart(AccuracyExplosionSelectionIn, analysisDataEA, 0.5, 1.5, '#D5544B'),
                     labels = c("1", "2"),
                     ncol = 1, nrow = 2
)

################# Differ

DiffListExplIn = AccuracyListSelectionIn/AccuracyExplosionSelectionIn
A3 = bootstrapMeanCI(DiffListExplIn)
cimax3 = A3[3]
cimin3 = A3[2]
mean3 = A3[1]

analysisData3 = c()
analysisData3$ratio = c("List/Explosion")
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.6, ymax=1.5, "", "Pair-wise differences. Error Bars, CIs")

figure_position_diffAccuracyIn <- SingleViolinChart(DiffListExplIn, analysisData3, 0, 2.5, '#30A479')


# Outside Cells
data = read.table("../analysis_data/position.csv", header=T, sep=",")
data = aggregate(data, by=list(P=data$P,Position=data$Position,Technique=data$Technique), FUN=mean, na.rm=TRUE)

AccuracyListSelectionIn = subset(data, Position==1 & Technique=="ListSelection")$correctness
AccuracyExplosionSelectionIn = subset(data, Position==1 & Technique=="ExplosionSelection")$correctness

AList = bootstrapMeanCI(AccuracyListSelectionIn)
AExplosion = bootstrapMeanCI(AccuracyExplosionSelectionIn)

cimaxL = AList[3]
cimaxE = AExplosion[3]
ciminL = AList[2]
ciminE = AExplosion[2]
meanListAccuracy = AList[1]
meanExplosionAccuracy = AExplosion[1]

analysisDataLA = c()
analysisDataLA$ratio = c("List") 
analysisDataLA$pointEstimate = c(meanListAccuracy)
analysisDataLA$ci.max = c(cimaxL)
analysisDataLA$ci.min = c(ciminL)

analysisDataEA = c()
analysisDataEA$ratio = c("Explosion")
analysisDataEA$pointEstimate = c(meanExplosionAccuracy)
analysisDataEA$ci.max = c(cimaxE)
analysisDataEA$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("ListSelection","ExplosionSelection")
analysisData$pointEstimate = c(meanListAccuracy, meanExplosionAccuracy)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=0.85, ymax=1.1, "", "Correctness per Technique in s. Error Bars, 95% CHIs")

figure_position_meanAccuracyOut <- ggarrange(SingleViolinChart(AccuracyListSelectionIn, analysisDataLA, 0.5, 1.5, '#E69F00'),
                     SingleViolinChart(AccuracyExplosionSelectionIn, analysisDataEA, 0.5, 1.5, '#D5544B'),
                     labels = c("1", "2"),
                     ncol = 1, nrow = 2
)

################# Differ
DiffListExplIn = AccuracyListSelectionIn/AccuracyExplosionSelectionIn
A3 = bootstrapMeanCI(DiffListExplIn)
cimax3 = A3[3]
cimin3 = A3[2]
mean3 = A3[1]

analysisData3 = c()
analysisData3$ratio = c("List/Explosion")     # 1: list selection; 2: explosion view selection; 3: combination
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.6, ymax=1.5, "", "Pair-wise differences. Error Bars, CIs")

figure_position_diffAccuracyOut <- SingleViolinChart(DiffListExplIn, analysisData3, 0.5, 2, '#30A479')



##############################################
####### two positions & clicking ratio #######
##############################################

# inside

data = read.table("../analysis_data/position.csv", header=T, sep=",")
data = aggregate(data, by=list(P=data$P,Position=data$Position,Technique=data$Technique), FUN=mean, na.rm=TRUE)

ValidListSelectionIn = subset(data, Position==0 & Technique=="ListSelection")$validClickingRatio
ValidExplosionSelectionIn = subset(data, Position==0 & Technique=="ExplosionSelection")$validClickingRatio

VList = bootstrapMeanCI(ValidListSelectionIn)
VExplosion = bootstrapMeanCI(ValidExplosionSelectionIn)

cimaxL = VList[3]
cimaxE = VExplosion[3]
ciminL = VList[2]
ciminE = VExplosion[2]
meanListValid = VList[1]
meanExplosionValid = VExplosion[1]

analysisDataLV = c()
analysisDataLV$ratio = c("List")     # 1: list selection; 2: explosion view selection; 3: combination
analysisDataLV$pointEstimate = c(meanListValid)
analysisDataLV$ci.max = c(cimaxL)
analysisDataLV$ci.min = c(ciminL)

analysisDataEV = c()
analysisDataEV$ratio = c("Explosion")     # 1: list selection; 2: explosion view selection; 3: combination
analysisDataEV$pointEstimate = c(meanExplosionValid)
analysisDataEV$ci.max = c(cimaxE)
analysisDataEV$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("ListSelection","ExplosionSelection")
analysisData$pointEstimate = c(meanListValid, meanExplosionValid)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=0, ymax=5, "", "Correctness per Technique in s. Error Bars, 95% CHIs")

figure_position_meanClickingIn <- ggarrange(SingleViolinChart(ValidListSelectionIn, analysisDataLV, 0, 4, '#E69F00'),
                     SingleViolinChart(ValidExplosionSelectionIn, analysisDataEV, 0, 4, '#D5544B'),
                     labels = c("1", "2"),
                     ncol = 1, nrow = 2
)


# diff
DivListExpl = ValidListSelectionIn/ValidExplosionSelectionIn
A3 = bootstrapMeanCI(DivListExpl)
mean3 = A3[1]
cimax3 = A3[3]
cimin3 = A3[2]

analysisData3 = c()
analysisData3$ratio = c("1/2")     # 1: list selection; 2: explosion view selection; 3: combination
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.75, ymax=1.25, "", "Pair-wise differences. Error Bars, CIs")

figure_position_diffClickingIn <- SingleViolinChart(DivListExpl, analysisData3, 0, 1.5, '#30A479')



# outside
data = read.table("../analysis_data/position.csv", header=T, sep=",")
data = aggregate(data, by=list(P=data$P,Position=data$Position,Technique=data$Technique), FUN=mean, na.rm=TRUE)

ValidListSelectionIn = subset(data, Position==1 & Technique=="ListSelection")$validClickingRatio
ValidExplosionSelectionIn = subset(data, Position==1 & Technique=="ExplosionSelection")$validClickingRatio

VList = bootstrapMeanCI(ValidListSelectionIn)
VExplosion = bootstrapMeanCI(ValidExplosionSelectionIn)

cimaxL = VList[3]
cimaxE = VExplosion[3]

ciminL = VList[2]
ciminE = VExplosion[2]

meanListValid = VList[1]
meanExplosionValid = VExplosion[1]

analysisDataLV = c()
analysisDataLV$ratio = c("List") 
analysisDataLV$pointEstimate = c(meanListValid)
analysisDataLV$ci.max = c(cimaxL)
analysisDataLV$ci.min = c(ciminL)

analysisDataEV = c()
analysisDataEV$ratio = c("Explosion")
analysisDataEV$pointEstimate = c(meanExplosionValid)
analysisDataEV$ci.max = c(cimaxE)
analysisDataEV$ci.min = c(ciminE)

analysisData = c()
analysisData$ratio = c("ListSelection","ExplosionSelection")
analysisData$pointEstimate = c(meanListValid, meanExplosionValid)
analysisData$ci.max = c(cimaxL, cimaxE)
analysisData$ci.min = c(ciminL, ciminE)

datatoprint <- data.frame(factor(analysisData$ratio), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData$ratio, nbTechs=2, ymin=0, ymax=5, "", "Correctness per Technique in s. Error Bars, 95% CHIs")

figure_position_meanClickingOut <- ggarrange(SingleViolinChart(ValidListSelectionIn, analysisDataLV, 0, 4, '#E69F00'),
                     SingleViolinChart(ValidExplosionSelectionIn, analysisDataEV, 0, 4, '#D5544B'),
                     labels = c("1", "2"),
                     ncol = 1, nrow = 2
)

# diff
DivListExpl = ValidListSelectionIn/ValidExplosionSelectionIn
A3 = bootstrapMeanCI(DivListExpl)
mean3 = A3[1]
cimax3 = A3[3]
cimin3 = A3[2]

analysisData3 = c()
analysisData3$ratio = c("List/Explosion")
analysisData3$pointEstimate = c(mean3)
analysisData3$ci.max = c(cimax3)
analysisData3$ci.min = c(cimin3)

datatoprint <- data.frame(factor(analysisData3$ratio), analysisData3$pointEstimate, analysisData3$ci.max, analysisData3$ci.min)
colnames(datatoprint) <- c("Technique", "mean_time", "lowerBound_CI", "upperBound_CI")
barChart(datatoprint, analysisData3$ratio, nbTechs=1, ymin=0.75, ymax=1.25, "", "Pair-wise differences. Error Bars, CIs")

figure_position_diffClickingOut <- SingleViolinChart(DivListExpl, analysisData3, 0, 1.5, '#30A479')






















